==> aliyun-sdk-mns-1.1.2-sources.jar: com/aliyun/mns/model/serialize/topic/AbstractSubscriptionDeserializer.java <==
package com.aliyun.mns.model.serialize.topic;

import com.aliyun.mns.model.SubscriptionMeta;
import com.aliyun.mns.model.serialize.XMLDeserializer;
import org.w3c.dom.Element;

import static com.aliyun.mns.common.MNSConstants.*;

public abstract class AbstractSubscriptionDeserializer<T> extends XMLDeserializer<T> {
    private SubscriptionMeta.NotifyStrategy str2Strategy(String str) {
        if (str.trim().equalsIgnoreCase(SubscriptionMeta.NotifyStrategy.BACKOFF_RETRY.toString())) {
            return SubscriptionMeta.NotifyStrategy.BACKOFF_RETRY;
        } else if (str.trim().equalsIgnoreCase(SubscriptionMeta.NotifyStrategy.EXPONENTIAL_DECAY_RETRY.toString())) {
            return SubscriptionMeta.NotifyStrategy.EXPONENTIAL_DECAY_RETRY;
        } else {
            return SubscriptionMeta.NotifyStrategy.BACKOFF_RETRY;
        }
    }
    
    private SubscriptionMeta.NotifyContentFormat str2Format(String str) {
        if (str.trim().equalsIgnoreCase(SubscriptionMeta.NotifyContentFormat.SIMPLIFIED.toString())) {
            return SubscriptionMeta.NotifyContentFormat.SIMPLIFIED;
        }
        else {
            return SubscriptionMeta.NotifyContentFormat.XML;
        }
    }

    protected SubscriptionMeta parseMeta(Element root) {
        SubscriptionMeta meta = new SubscriptionMeta();
        String topicName = safeGetElementContent(root, TOPIC_NAME_TAG, null);
        if (topicName != null) {
            meta.setTopicName(topicName);
        }

        String subscriptionName = safeGetElementContent(root, SUBSCRIPTION_NAME_TAG, null);
        if (subscriptionName != null) {
            meta.setSubscriptionName(subscriptionName);
        }

        String topicOwner = safeGetElementContent(root, TOPIC_OWNER_TAG, null);
        if (topicOwner != null) {
            meta.setTopicOwner(topicOwner);
        }

        String status = safeGetElementContent(root, SUBSCRIPTION_STATUS, null);
        if (status != null) {
            meta.setStatus(status);
        }

        String endpoint = safeGetElementContent(root, ENDPOINT_TAG, null);
        if (endpoint != null) {
            meta.setEndpoint(endpoint);
        }

        String notifyStrategy = safeGetElementContent(root, NOTIFY_STRATEGY_TAG, null);
        if (notifyStrategy != null) {
            meta.setNotifyStrategy(str2Strategy(notifyStrategy));
        }

        String createTime = safeGetElementContent(root, CREATE_TIME_TAG, null);
        if (createTime != null) {
            meta.setCreateTime(Long.parseLong(createTime));
        }

        String lastModifyTime = safeGetElementContent(root, LASTMODIFYTIME_TAG, null);
        if (lastModifyTime != null) {
            meta.setLastModifyTime(Long.parseLong(lastModifyTime));
        }

        String notifyContentFormat = safeGetElementContent(root, NOTIFY_CONTENT_FORMAT_TAG, DEFAULT_NOTIFY_CONTENT_TYPE);
        meta.setNotifyContentFormat(str2Format(notifyContentFormat));

        String subsriptionURL = safeGetElementContent(root, SUBSCRIPTION_URL_TAG, null);
        meta.setSubscriptionURL(subsriptionURL);
        
        return meta;
    }

}

==> aliyun-sdk-mns-1.1.7-sources.jar: com/aliyun/mns/model/serialize/topic/AbstractSubscriptionDeserializer.java <==
package com.aliyun.mns.model.serialize.topic;

import com.aliyun.mns.model.SubscriptionMeta;
import com.aliyun.mns.model.serialize.XMLDeserializer;
import org.w3c.dom.Element;

import static com.aliyun.mns.common.MNSConstants.*;

public abstract class AbstractSubscriptionDeserializer<T> extends XMLDeserializer<T> {
    private SubscriptionMeta.NotifyStrategy str2Strategy(String str) {
        if (str.trim().equalsIgnoreCase(SubscriptionMeta.NotifyStrategy.BACKOFF_RETRY.toString())) {
            return SubscriptionMeta.NotifyStrategy.BACKOFF_RETRY;
        } else if (str.trim().equalsIgnoreCase(SubscriptionMeta.NotifyStrategy.EXPONENTIAL_DECAY_RETRY.toString())) {
            return SubscriptionMeta.NotifyStrategy.EXPONENTIAL_DECAY_RETRY;
        } else {
            return SubscriptionMeta.NotifyStrategy.BACKOFF_RETRY;
        }
    }
    
    private SubscriptionMeta.NotifyContentFormat str2Format(String str) {
        if (str.trim().equalsIgnoreCase(SubscriptionMeta.NotifyContentFormat.SIMPLIFIED.toString())) {
            return SubscriptionMeta.NotifyContentFormat.SIMPLIFIED;
        }
        else if (str.trim().equalsIgnoreCase(SubscriptionMeta.NotifyContentFormat.JSON.toString())) {
            return SubscriptionMeta.NotifyContentFormat.JSON;
        }
        else {
            return SubscriptionMeta.NotifyContentFormat.XML;
        }
    }

    protected SubscriptionMeta parseMeta(Element root) {
        SubscriptionMeta meta = new SubscriptionMeta();
        String topicName = safeGetElementContent(root, TOPIC_NAME_TAG, null);
        if (topicName != null) {
            meta.setTopicName(topicName);
        }

        String subscriptionName = safeGetElementContent(root, SUBSCRIPTION_NAME_TAG, null);
        if (subscriptionName != null) {
            meta.setSubscriptionName(subscriptionName);
        }

        String topicOwner = safeGetElementContent(root, TOPIC_OWNER_TAG, null);
        if (topicOwner != null) {
            meta.setTopicOwner(topicOwner);
        }

        String status = safeGetElementContent(root, SUBSCRIPTION_STATUS, null);
        if (status != null) {
            meta.setStatus(status);
        }

        String endpoint = safeGetElementContent(root, ENDPOINT_TAG, null);
        if (endpoint != null) {
            meta.setEndpoint(endpoint);
        }

        String notifyStrategy = safeGetElementContent(root, NOTIFY_STRATEGY_TAG, null);
        if (notifyStrategy != null) {
            meta.setNotifyStrategy(str2Strategy(notifyStrategy));
        }

        String createTime = safeGetElementContent(root, CREATE_TIME_TAG, null);
        if (createTime != null) {
            meta.setCreateTime(Long.parseLong(createTime));
        }

        String lastModifyTime = safeGetElementContent(root, LASTMODIFYTIME_TAG, null);
        if (lastModifyTime != null) {
            meta.setLastModifyTime(Long.parseLong(lastModifyTime));
        }

        String notifyContentFormat = safeGetElementContent(root, NOTIFY_CONTENT_FORMAT_TAG, DEFAULT_NOTIFY_CONTENT_TYPE);
        meta.setNotifyContentFormat(str2Format(notifyContentFormat));
        
        String filterTag = safeGetElementContent(root, FILTER_TAG_TAG, null);
        if (filterTag != null) {
            meta.setFilterTag(filterTag);
        }

        String subsriptionURL = safeGetElementContent(root, SUBSCRIPTION_URL_TAG, null);
        meta.setSubscriptionURL(subsriptionURL);
        
        return meta;
    }

}
